/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISMimeJSHelper.idl
 */

#ifndef __gen_nsISMimeJSHelper_h__
#define __gen_nsISMimeJSHelper_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgCompFields; /* forward declaration */

class nsIX509Cert; /* forward declaration */


/* starting interface:    nsISMimeJSHelper */
#define NS_ISMIMEJSHELPER_IID_STR "a54e3c8f-a000-4901-898f-fafb297b1546"

#define NS_ISMIMEJSHELPER_IID \
  {0xa54e3c8f, 0xa000, 0x4901, \
    { 0x89, 0x8f, 0xfa, 0xfb, 0x29, 0x7b, 0x15, 0x46 }}

class NS_NO_VTABLE nsISMimeJSHelper : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISMIMEJSHELPER_IID)

  /**
   * Obtains detailed information about the certificate availability
   * status of email recipients.
   *
   * @param compFields - Attributes of the composed message
   *
   * @param count - The number of entries in returned arrays
   *
   * @param emailAddresses - The list of all recipient email addresses
   *
   * @param certVerification - The verification/validity status of recipient certs
   *
   * @param certIssuedInfos - If a recipient cert was found, when has it been issued?
   *
   * @param certExpiredInfos - If a recipient cert was found, when will it expire?
   *
   * @param certs - The recipient certificates, which can contain null for not found
   *
   * @param canEncrypt - whether valid certificates have been found for all recipients
   *
   * @exception NS_ERROR_FAILURE - unexptected failure
   *
   * @exception NS_ERROR_OUT_OF_MEMORY - could not create the out list
   *
   * @exception NS_ERROR_INVALID_ARG
   */
  /* void getRecipientCertsInfo (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses, [array, size_is (count)] out long certVerification, [array, size_is (count)] out wstring certIssuedInfos, [array, size_is (count)] out wstring certExpiresInfos, [array, size_is (count)] out nsIX509Cert certs, out PRBool canEncrypt); */
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses, PRInt32 **certVerification, PRUnichar ***certIssuedInfos, PRUnichar ***certExpiresInfos, nsIX509Cert ***certs, PRBool *canEncrypt) = 0;

  /**
   * Obtains a list of email addresses where valid email recipient certificates
   * are not yet available.
   *
   * @param compFields - Attributes of the composed message
   *
   * @param count - The number of returned email addresses
   *
   * @param emailAddresses - The list of email addresses without valid certs
   *
   * @exception NS_ERROR_FAILURE - unexptected failure
   *
   * @exception NS_ERROR_OUT_OF_MEMORY - could not create the out list
   *
   * @exception NS_ERROR_INVALID_ARG
   */
  /* void getNoCertAddresses (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses); */
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISMIMEJSHELPER \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses, PRInt32 **certVerification, PRUnichar ***certIssuedInfos, PRUnichar ***certExpiresInfos, nsIX509Cert ***certs, PRBool *canEncrypt); \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISMIMEJSHELPER(_to) \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses, PRInt32 **certVerification, PRUnichar ***certIssuedInfos, PRUnichar ***certExpiresInfos, nsIX509Cert ***certs, PRBool *canEncrypt) { return _to GetRecipientCertsInfo(compFields, count, emailAddresses, certVerification, certIssuedInfos, certExpiresInfos, certs, canEncrypt); } \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses) { return _to GetNoCertAddresses(compFields, count, emailAddresses); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISMIMEJSHELPER(_to) \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses, PRInt32 **certVerification, PRUnichar ***certIssuedInfos, PRUnichar ***certExpiresInfos, nsIX509Cert ***certs, PRBool *canEncrypt) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRecipientCertsInfo(compFields, count, emailAddresses, certVerification, certIssuedInfos, certExpiresInfos, certs, canEncrypt); } \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNoCertAddresses(compFields, count, emailAddresses); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSMimeJSHelper : public nsISMimeJSHelper
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISMIMEJSHELPER

  nsSMimeJSHelper();
  virtual ~nsSMimeJSHelper();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSMimeJSHelper, nsISMimeJSHelper)

nsSMimeJSHelper::nsSMimeJSHelper()
{
  /* member initializers and constructor code */
}

nsSMimeJSHelper::~nsSMimeJSHelper()
{
  /* destructor code */
}

/* void getRecipientCertsInfo (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses, [array, size_is (count)] out long certVerification, [array, size_is (count)] out wstring certIssuedInfos, [array, size_is (count)] out wstring certExpiresInfos, [array, size_is (count)] out nsIX509Cert certs, out PRBool canEncrypt); */
NS_IMETHODIMP nsSMimeJSHelper::GetRecipientCertsInfo(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses, PRInt32 **certVerification, PRUnichar ***certIssuedInfos, PRUnichar ***certExpiresInfos, nsIX509Cert ***certs, PRBool *canEncrypt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getNoCertAddresses (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses); */
NS_IMETHODIMP nsSMimeJSHelper::GetNoCertAddresses(nsIMsgCompFields *compFields, PRUint32 *count, PRUnichar ***emailAddresses)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISMimeJSHelper_h__ */
